@@ -3,14 +3,12 @@
 
 __all__ = ['getmaskingstatus']
 
-
 import portage
 from portage import eapi_is_supported, _eapi_is_deprecated
 from portage.exception import InvalidDependString
 from portage.localization import _
 from portage.package.ebuild.config import config
-from portage.versions import catpkgsplit, _pkg_str
-
+from portage.versions import _pkg_str
 
 class _UnmaskHint:
 
@@ -85,7 +83,7 @@ def _getmaskingstatus(mycpv, settings, portdb, myrepo=None):
 	restrict = metadata["RESTRICT"]
 	if not eapi_is_supported(eapi):
 		return [_MaskReason("EAPI", "EAPI %s" % eapi)]
-	elif _eapi_is_deprecated(eapi) and not installed:
+	if _eapi_is_deprecated(eapi) and not installed:
 		return [_MaskReason("EAPI", "EAPI %s" % eapi)]
 	egroups = settings.configdict["backupenv"].get(
 		"ACCEPT_KEYWORDS", "").split()
